
ProximoGrid.StatusCache = {};
ProximoGridStatus = {}


ProximoGridStatus.__index = ProximoGridStatus

function ProximoGridStatus.NewModule(name, db)

	local status = {};
	setmetatable(status,ProximoGridStatus);
	status.name = name;
	status.header = "Unnamed";
	status.options = {};
	status.enabled = false;

	ProximoGrid.profileDefault.status[name] = {
		["name"] = name,
		["db"] = db
	}
	if (ProximoGrid.profileDefault.status[name].db.announcements == nil) then
		ProximoGrid.profileDefault.status[name].db.announcements = {};
	end
	status.initFrame = CreateFrame("Frame");
	status.initFrame:SetScript("OnEvent", function()
		if (status.OnInitialize) then
			status:SetOptions(status.options);
			status:OnInitialize()
		end
	end);
	status.initFrame:RegisterEvent("PLAYER_ENTERING_WORLD");
	status.frame = CreateFrame("Frame");
	status.frame:Hide();
	status.self = status;
	status.frame:SetScript("OnEvent", function() 
		status[event](event, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11, arg13, arg14,arg15,arg16);
	end);
	return status;
end
function ProximoGridStatus:SendAnnouncement(msg, shortName)
	ProximoGrid:SendAnnouncement(msg, shortName);
end


function ProximoGridStatus:RegisterStatus(shortName, name)
	ProximoGrid.RegisteredStatus[shortName] = {
		["name"] = name,
		["enabled"] = true
	}
	ProximoGrid:UpdateIndicatorOptions();
end


function ProximoGridStatus:UnregisterStatus(shortName)
	for number, unitFrame in pairs (ProximoGrid.UnitFrames) do
		self:SendStatusLost(unitFrame.unitGUID, shortName);
	end
	ProximoGrid.RegisteredStatus[shortName] = nil;
	ProximoGrid:UpdateIndicatorOptions();
end

function ProximoGridStatus:RegisterAnnouncement(shortName, name)
	ProximoGrid.RegisteredAnnouncement[shortName] = {
		["name"] = name,
		["enabled"] = false,
		["statusModule"] = self;
	}
	ProximoGrid:UpdateAnnouncementOptions();
end

function ProximoGridStatus:UnregisterAnnouncement(shortName, name)
	ProximoGrid.RegisteredAnnouncement[shortName] = nil;
	ProximoGrid:UpdateAnnouncementOptions();
end

function ProximoGridStatus:IsEventRegistered(event)
	if (string.sub(event, 1, 11) == "PROXIMOGRID") then
		ProximoGrid:IsEventRegistered(event, self.OnEvent, self);
	else
		self.frame:IsEventRegistered(event);
	end
end

function ProximoGridStatus:RegisterEvent(event)
	if (string.sub(event, 1, 11) == "PROXIMOGRID") then
		ProximoGrid:RegisterProximoGridEvent(event, self.OnEvent, self);
	else
		self.frame:RegisterEvent(event);
	end
end

function ProximoGridStatus:UnregisterEvent(event)
	if (string.sub(event, 1, 11) == "PROXIMOGRID") then
		ProximoGrid:UnregisterProximoGridEvent(event, self);
	else
		self.frame:UnregisterEvent(event);
	end
end

function ProximoGridStatus:OnEvent(event, ...)
	self[event](event,...);
end

function ProximoGridStatus:SetOptions(options)
	self.db = ProximoGrid.db.profile.status[self.name].db;
	ProximoGrid:UpdateStatusOptions(self.name, self.header, options);
end

function ProximoGridStatus:Enable(value)
	if (value == self.enabled) then
		return;
	end
	self.enabled = value;
	if (value) then
		self:OnEnable();
	else
		self:OnDisable();
	end

end

function ProximoGridStatus:OnEnable()

end

function ProximoGridStatus:OnDisable()

end

function ProximoGridStatus:SendStatusGained(unitID, name, status, priority, range, color, text,  value, maxValue, texture, start, duration, stack)
	local cache = ProximoGrid.StatusCache;
	local cached;
	if (unitID==nil) then
		DEFAULT_CHAT_FRAME:AddMessage(self.name);
	end
	
	if (cache[unitID] == nil) then
		cache[unitID] = {};
	end
	if (cache[unitID][status] == nil) then
		cache[unitID][status] = {};
	end
	cached = cache[unitID][status];
	if cached and
		cached.priority == priority and
		cached.range == range and
		cached.color.r == color.r and
		cached.color.g == color.g and
		cached.color.b == color.b and
		cached.color.a == color.a and
		cached.text == text and
		cached.value == value and
		cached.maxValue == maxValue and
		cached.texture == texture and
		cached.start == start and
		cached.duration == duration and
		cached.stack == stack and
		cached.name == name then
		return false;
	end
	
	--if cached and not (
	--	cached.priority and
	--	cached.range and
	--	cached.color and
	--	cached.text and
	--	cached.value and
	--	cached.maxValue and
	--	cached.texture and
	--	cached.start and
	--	cached.duration and
	--	cached.stack and
	--	cached.name ) then
	--	DEFAULT_CHAT_FRAME:AddMessage("Error:"..self.name.." Text: "..(cached.text or "").." Name: "..(name or ""));
--
	--end
	
	-- update cache
	cached.priority = priority;
	cached.range = range;
	cached.color = color;
	cached.text = text;
	cached.value = value;
	cached.maxValue = maxValue;
	cached.texture = texture;
	cached.start = start;
	cached.duration = duration;
	cached.stack = stack;
	cached.name = name;
		--if (data.status["status"] ~= nil and data.status["status"] ~= false) then
--			ProximoGrid:UpdateIndicator(data.name, name, status);
--		end
	ProximoGridStatus:UpdateStatus(unitID, status);
	return true;

end

function ProximoGridStatus:SendStatusLost(unitID, status)
	local cache = ProximoGrid.StatusCache;
	if (cache[unitID] ~= nil and cache[unitID][status] ~= nil) then
		cache[unitID][status] = nil;
		ProximoGridStatus:UpdateStatus(unitID, status);
	end
end

function ProximoGridStatus:OnInit()
	self:SetOptions(self.options);
	self:OnInitialize();
end

function ProximoGridStatus:OnInitialize()

end

function ProximoGridStatus:RegisterDB()
	--DEFAULT_CHAT_FRAME:AddMessage(self.."test13213"..getglobal("ProximoGrid").db.profile.frame.padding);
end

function ProximoGridStatus:UpdateStatus(unitID, status)
	local cache = ProximoGrid.StatusCache;

	for indicator, indicatorData in pairs (ProximoGrid.Indicators) do
		local data = ProximoGrid.db.profile.indicators[indicator];
		if (data.status[status] ~= nil) then
			local tmpStatus;
			local tmpPriority = 0;
			for status, active in pairs(data.status) do
				if (active and cache[unitID][status] ~= nil and cache[unitID][status].priority > tmpPriority) then
					tmpPriority = cache[unitID][status].priority;
					tmpStatus = status;
					if (tmpPriority>=99) then
						break;
					end
				end
			end
			if (tmpStatus ~= nil) then
				ProximoGrid:UpdateIndicator(indicator, unitID, tmpStatus);
			else
				ProximoGrid:ResetIndicator(indicator, unitID)
			end
		end
	end
end