local L = LibStub("AceLocale-3.0"):GetLocale("ProximoGrid", true)
StatusTarget = ProximoGridStatus.NewModule("StatusTarget", {
	yourTarget = {
		color = {1, 1, 1, 1},
		priority = 90
	},
	partyTarget = {
		useClassColors = true,
		color = {1, 1, 1, 1},
		priority = 89
	},
});

StatusTarget.header = L["Target"];
StatusTarget.options = {
	yourTarget = {
		type = "group",
		name = L["Your Target"],
		desc = L["Your current target."],
		args = {
			color = {
				type = "color",
				name = L["Color"],
				desc = L["Color."],
				get = function()
					local tmpColor = StatusTarget.db.yourTarget.color;
					return tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4]
				end,
				set = function(r, g, b, a)
					local tmpColor = StatusTarget.db.yourTarget.color;
					tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4] = r, g, b, a or 1
				end,
				hasAlpha = false,
			},
			alpha = {
				type = "range",
				name = L["Alpha"],
				desc = L["Alpha."],
				get = function()
					return StatusTarget.db.yourTarget.color[4];
				end,
				set = function(v)
					StatusTarget.db.yourTarget.color[4] = v;
				end,
				min = 0,
				max = 1,
				step = 0.01
			},
			priority = {
				type = "range",
				name = L["Priority"],
				desc = L["Priority."],
				get = function()
					return StatusTarget.db.yourTarget.priority;
				end,
				set = function(v)
					StatusTarget.db.yourTarget.priority = v;
				end,
				min = 1,
				max = 99,
				step = 1
			}
		}
	},
	partysTarget = {
		type = "group",
		name = L["Party Target"],
		desc = L["This will show what people in your party/raid have as target."],
		args = {
			classColor = {
				type = "toggle",
				name = L["Use Class Color"],
				desc = L["Use Blizzard's default class colors."],
				get = function()
					return StatusTarget.db.partyTarget.useClassColors;
				end,
				set = function(v)
					StatusTarget.db.partyTarget.useClassColors = v;
				end,
			},
			color = {
				type = "color",
				name = L["Color"],
				desc = L["The color that will be used if 'Use Class Colors' is not set."],
				get = function()
					local tmpColor = StatusTarget.db.partyTarget.color;
					return tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4]
				end,
				set = function(r, g, b, a)
					local tmpColor = StatusTarget.db.partyTarget.color;
					tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4] = r, g, b, a or 1
				end,
				hasAlpha = false,
			},
			alpha = {
				type = "range",
				name = L["Alpha"],
				desc = L["Alpha."],
				get = function()
					return StatusTarget.db.partyTarget.color[4];
				end,
				set = function(v)
					StatusTarget.db.partyTarget.color[4] = v;
				end,
				min = 0,
				max = 1,
				step = 0.01
			},
			priority = {
				type = "range",
				name = L["Priority"],
				desc = L["Priority."],
				get = function()
					return StatusTarget.db.partyTarget.priority;
				end,
				set = function(v)
					StatusTarget.db.partyTarget.priority = v;
				end,
				min = 1,
				max = 99,
				step = 1
			}
		}
	},
}
function StatusTarget:OnInitialize()
	StatusTarget:RegisterStatus("statusPlayerTarget", L["Your Target"]);
	StatusTarget:RegisterStatus("statusPartyTarget", L["Party Target"]);
end

function StatusTarget:OnEnable()
	StatusTarget:RegisterEvent("PLAYER_TARGET_CHANGED");
	StatusTarget:RegisterEvent("UNIT_TARGET");
end

function StatusTarget:OnDisable()
	StatusTarget:UnregisterEvent("PLAYER_TARGET_CHANGED");
	StatusTarget:UnregisterEvent("UNIT_TARGET");
end

StatusTarget.lastTarget = "";

function StatusTarget:PLAYER_TARGET_CHANGED()
	local unitID;
	if (ProximoGrid:inArenaZone()) then
		for i=1, 5 do
			if (UnitGUID("arena"..i) ~= nil and UnitGUID("target") == UnitGUID("arena"..i)) then
				unitID = "arena"..i;
				break;
			end
		end
	else
		unitID = UnitGUID("target")
	end
	if (lastTarget ~= nil and ProximoGrid:GetUnitFrameByUnitID(lastTarget) ~= nil) then
		StatusTarget:SendStatusLost(lastTarget, "statusPlayerTarget");
		lastTarget = "";
	end
	if (ProximoGrid:GetUnitFrameByUnitID(unitID) ~= nil) then
		local tmpColor = StatusTarget.db.yourTarget.color;
		local r, g, b, a = tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4];
		local unitName = UnitName("target");
		StatusTarget:SendStatusGained(unitID, unitName, "statusPlayerTarget", StatusTarget.db.yourTarget.priority, true, {["r"] = r,["g"] =g,["b"] =b, ["a"] = a}, L["Target"],  0, 0, nil, 0, 0, 0);
		lastTarget = unitID;
	end
end

function StatusTarget:UNIT_TARGET(unitID)
	local tmpOpponents = {};
	if (ProximoGrid:inArenaZone() and unitID:sub(1,5) ~= "party") then
		return;
	end
	if (not ProximoGrid:inArenaZone()) then
		for i=1, ProximoGrid:GetRows()*ProximoGrid:GetColumns() do
			local unitID = ProximoGrid.UnitFrames[i].unitID;
			if (unitID ~= nil) then
				local opponent = ProximoGrid.Opponents[unitID];
				local foundLink;
				for unitLink, enabled in pairs (opponent.unitLinks) do
					if (unitLink:find("pet")~=nil) then
					elseif (unitLink:sub(1,5) =="party") then
						tmpOpponents[i] = unitLink:sub(1, 6);
						break;
					elseif (unitLink:sub(1,4)=="raid") then
						tmpOpponents[i] = unitLink:sub(1, 5);
						local num = unitLink:sub(6,6);
						if (tonumber(num) ~= nil) then
							tmpOpponents[i] = tmpOpponents[i]..num;
						end
						break;
					end
				end
			end
		end
	else
		for i=1, 5 do
			for x=1, 5 do
				if (UnitGUID("party"..i.."target") == UnitGUID("arena"..x)) then
					tmpOpponents[x] = "party"..i
					break;
				end
			end
		end
	end
	for i=1, ProximoGrid:GetRows()*ProximoGrid:GetColumns() do 
		local unitID = ProximoGrid.UnitFrames[i].unitID;
		if (tmpOpponents[i] == nil) then
			StatusTarget:SendStatusLost(unitID, "statusPartyTarget");
		else
			local tmpColor;
			if (StatusTarget.db.partyTarget.useClassColors) then
				r, g, b, a = ProximoGrid:GetColor("class", UnitClass(tmpOpponents[i]));
			else
				tmpColor = StatusTarget.db.partyTarget.color;
				r, g, b, a = tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4];
			end
			StatusTarget:SendStatusGained(unitID, unitName, "statusPartyTarget", StatusTarget.db.partyTarget.priority, true, {["r"] = r,["g"] =g,["b"] =b, ["a"] = a}, L["Target"],  0, 0, nil, 0, 0, 0);
		end
	end
end